library("testthat")
library("scoring")

test_check("scoring")
